
.. image:: https://img.shields.io/static/v1?label=os&message=Windows&color=blue

.. image:: https://img.shields.io/static/v1?label=mchp-flasher-essentials&message=Stable&color=green

.. image:: https://img.shields.io/pypi/v/mchp-flasher-essentials.svg?label=pypi

.. image:: https://img.shields.io/static/v1?label=chipset&message=HB20&color=blueviolet

|
|

.. image:: https://www.microchip.com/content/experience-fragments/mchp/en_us/site/header/master/_jcr_content/root/responsivegrid/header/logo.coreimg.100.300.png/1605828081463/microchip.png

HB20 Flasher require specific versions of Python packages to run properly. This package install all the necessary packages.

How to install
--------------
.. code-block:: bash

    pip install mchp-flasher-essentials

List of packages
----------------
#. `colorama==0.4.4 <https://pypi.org/project/colorama/0.4.4/>`_.
#. `inputimeout==1.0.4 <https://pypi.org/project/inputimeout/1.0.4/>`_.
#. `intelhex==2.3.0 <https://pypi.org/project/intelhex/2.3.0/>`_.
#. `psutil==5.8.0 <https://pypi.org/project/psutil/5.8.0/>`_.
#. `PyDirectInput==1.0.4 <https://pypi.org/project/PyDirectInput/1.0.4/>`_.
#. `pyelftools==0.27 <https://pypi.org/project/pyelftools/0.27/>`_.
#. `pywin32==301 <https://pypi.org/project/pywin32/301/>`_.
#. `termcolor==1.1.0 <https://pypi.org/project/termcolor/1.1.0/>`_.


